diff -ruN subtitles-0.5.0/Makefile subtitles-0.5.0-darwin/Makefile
--- subtitles-0.5.0/Makefile	2006-04-28 17:21:39.000000000 +0300
+++ subtitles-0.5.0-darwin/Makefile	2007-03-26 17:57:37.000000000 +0300
@@ -12,12 +12,12 @@
 ### The version number of this plugin (taken from the main source file):
 
 VERSION = $(shell grep 'static const char \*VERSION *=' $(PLUGIN).c | awk '{ print $$6 }' | sed -e 's/[";]//g')
-APIVERSION = $(shell sed -ne '/define APIVERSION/ { s/^.*"\(.*\)".*$$/\1/; p }' $(VDRDIR)/config.h)
+APIVERSION = $(shell sed -ne '/define APIVERSION/s/^.*"\(.*\)".*$$/\1/p' $(VDRDIR)/config.h)
 
 ### The C++ compiler and options:
 
 CXX      ?= g++
-CXXFLAGS ?= -O2 -g -Wall -Woverloaded-virtual -fPIC
+CXXFLAGS ?= -O2 -g -Wall -Woverloaded-virtual -fPIC -fno-common -bundle -flat_namespace -undefined suppress
 
 ### The directory environment:
 
@@ -72,7 +72,7 @@
 all: libvdr-$(PLUGIN).so
 
 libvdr-$(PLUGIN).so: $(OBJS)
-	$(CXX) $(CXXFLAGS) -shared $(OBJS) -o $@
+	$(CXX) $(CXXFLAGS) -dynamic $(OBJS) -o $@
 	@cp $@ $(LIBDIR)/$@.$(APIVERSION)
 
 dist: clean
diff -ruN subtitles-0.5.0/Makefile.linux subtitles-0.5.0-darwin/Makefile.linux
--- subtitles-0.5.0/Makefile.linux	1970-01-01 02:00:00.000000000 +0200
+++ subtitles-0.5.0-darwin/Makefile.linux	2007-03-26 17:57:37.000000000 +0300
@@ -0,0 +1,87 @@
+#
+# Makefile for a Video Disk Recorder plugin
+#
+# $Id: Makefile,v 1.1 2005/02/15 10:08:00 opj Exp $
+
+# The official name of this plugin.
+# This name will be used in the '-P...' option of VDR to load the plugin.
+# By default the main source file also carries this name.
+#
+PLUGIN = subtitles
+
+### The version number of this plugin (taken from the main source file):
+
+VERSION = $(shell grep 'static const char \*VERSION *=' $(PLUGIN).c | awk '{ print $$6 }' | sed -e 's/[";]//g')
+APIVERSION = $(shell sed -ne '/define APIVERSION/ { s/^.*"\(.*\)".*$$/\1/; p }' $(VDRDIR)/config.h)
+
+### The C++ compiler and options:
+
+CXX      ?= g++
+CXXFLAGS ?= -O2 -g -Wall -Woverloaded-virtual -fPIC
+
+### The directory environment:
+
+DVBDIR = ../../../../DVB
+VDRDIR = ../../..
+LIBDIR = ../../lib
+TMPDIR = /tmp
+
+### Allow user defined options to overwrite defaults:
+
+-include $(VDRDIR)/Make.config
+
+### The version number of VDR (taken from VDR's "config.h"):
+
+VDRVERSION = $(shell grep 'define VDRVERSION ' $(VDRDIR)/config.h | awk '{ print $$3 }' | sed -e 's/"//g')
+
+### The name of the distribution archive:
+
+ARCHIVE = $(PLUGIN)-$(VERSION)
+PACKAGE = vdr-$(ARCHIVE)
+
+### Includes and Defines (add further entries here):
+
+INCLUDES += -I$(VDRDIR)/include -I$(DVBDIR)/include
+
+DEFINES += -D_GNU_SOURCE -DPLUGIN_NAME_I18N='"$(PLUGIN)"'
+
+ifdef DEBUG
+DEFINES += -DDEBUG
+endif
+
+### The object files (add further files here):
+
+OBJS = $(PLUGIN).o receiver.o object.o renderer.o region.o clut.o viewer.o dec.o replay.o configuration.o i18n.o page.o subtitle.o sync.o subfilter.o menu.o
+
+### Implicit rules:
+
+%.o: %.c
+	$(CXX) $(CXXFLAGS) -c $(DEFINES) $(INCLUDES) $<
+
+# Dependencies:
+
+MAKEDEP = g++ -MM -MG
+DEPFILE = .dependencies
+$(DEPFILE): Makefile
+	@$(MAKEDEP) $(DEFINES) $(INCLUDES) $(OBJS:%.o=%.c) > $@
+
+-include $(DEPFILE)
+
+### Targets:
+
+all: libvdr-$(PLUGIN).so
+
+libvdr-$(PLUGIN).so: $(OBJS)
+	$(CXX) $(CXXFLAGS) -shared $(OBJS) -o $@
+	@cp $@ $(LIBDIR)/$@.$(APIVERSION)
+
+dist: clean
+	@-rm -rf $(TMPDIR)/$(ARCHIVE)
+	@mkdir $(TMPDIR)/$(ARCHIVE)
+	@cp -a * $(TMPDIR)/$(ARCHIVE)
+	@tar czf $(PACKAGE).tgz -C $(TMPDIR) $(ARCHIVE)
+	@-rm -rf $(TMPDIR)/$(ARCHIVE)
+	@echo Distribution package created as $(PACKAGE).tgz
+
+clean:
+	@-rm -f $(OBJS) $(DEPFILE) *.so *.tgz core* *~
diff -ruN subtitles-0.5.0/subfilter.c subtitles-0.5.0-darwin/subfilter.c
--- subtitles-0.5.0/subfilter.c	2007-01-28 11:26:30.000000000 +0200
+++ subtitles-0.5.0-darwin/subfilter.c	2007-03-26 17:57:37.000000000 +0300
@@ -24,6 +24,10 @@
 #include <string.h>
 #include "menu.h"
 
+#ifdef __APPLE__
+#include <vdr/darwinutils.h>
+#endif
+
 
 class cOsdObject;
 
@@ -64,7 +68,7 @@
     int compositionPage;
     int ancillaryPage;
 
-    int fields = sscanf(s, "%a[^=]=%d+%d+%d+%d", &langbuf, &pid, &compositionPage, &ancillaryPage, &type);
+    int fields = sscanf_darwin(s, "%a[^=]=%d+%d+%d+%d", &langbuf, &pid, &compositionPage, &ancillaryPage, &type);
 
     int languageIndex = -1;
     if (langbuf)
@@ -203,7 +207,7 @@
     char* cidbuf = NULL;
     char* streamsbuf = NULL;
 
-    int fields = sscanf(s, "%a[^:]:%d:%a[^\n]", &cidbuf, &userLanguage, &streamsbuf);
+    int fields = sscanf_darwin(s, "%a[^:]:%d:%a[^\n]", &cidbuf, &userLanguage, &streamsbuf);
 
     bool ret = false;
 
